<script setup>
import { Head, Link, useForm } from '@inertiajs/inertia-vue3';
import Welcome from '@/Jetstream/Welcome.vue';
import JetLabel from '@/Jetstream/Label.vue';
import Datepicker from '@vuepic/vue-datepicker';
import '@vuepic/vue-datepicker/dist/main.css';
import JetDropdown from '@/Jetstream/Dropdown.vue';
import JetDropdownLink from '@/Jetstream/DropdownLink.vue';
import JetModal from '@/Jetstream/Modal.vue';
import JetButton from '@/Jetstream/Button.vue';
import mapboxgl from 'mapbox-gl';
import 'mapbox-gl/dist/mapbox-gl.css';
import Highcharts from 'highcharts';
import DK_Button from '@/components/dk_Button.vue';
import DK_Input from '@/components/dk_Input.vue';
import VueMultiselect from 'vue-multiselect';


let AppLayout;

if (window.location.origin.indexOf('localhost:8000') !== -1 || window.location.origin.indexOf('water.baltoro.app') !== -1) {
    AppLayout = require('@/Layouts/AppLayoutWater.vue').default;
} else {
    AppLayout = require('@/Layouts/AppLayoutCity.vue').default;
}

</script>

<style>
/* Radio */

input[type="radio"] {
    background-color: transparent;
    border-radius: 10px;
    cursor: pointer;
    display: inline-block;
    height: 15px;
    position: relative;
    width: 15px;
    -webkit-appearance: none;
}

input[type="radio"]:after {
    background-color: rgba(5, 255, 243, 0.1);
    border-radius: 25px;

    content: '';
    display: block;
    height: 10px;
    left: 4px;
    position: relative;
    top: 4px;
    width: 10px;
    border-width: 1px;
    border-color: rgba(175, 175, 175, 0.75);
}

input[type="radio"]:checked:after {
    background-color: rgba(5,255,243, 0.8);
    border-color: rgba(255, 250, 250, 0.9);
}

input[type="radio"]:hover:after {
    border-color: rgba(255, 250, 250, 0.65) ;
}

@keyframes pulse {

    0%,
    100% {
        opacity: 1;
    }

    50% {
        opacity: 0;
    }
}
</style>

<template>
    <AppLayout title="Profile">
        <div style="height: calc(100vh - 4.75rem);" v-if="this.screen_width >= 768"
            class="bg-darkblue-background px-8 z-0 overflow-y-scroll cursor-default">

            <div class="flex flex-col justify-end items-start w-full">
                <div class="grid gap-6 2xl:grid-cols-5 grid-cols-4 w-full">
                    <div class="flex gap-2 items-start justify-start w-fit mt-4">
                        <p class="text-white-snow font-light text-2xl w-full text-left">{{ this.$t('general.Profile Information') }}</p>
                    </div>
                    <div class="2xl:col-span-4 col-span-3 flex gap-2 items-end justify-between w-full">
                        <div class="flex flex-col w-full gap-6 items-start" v-bind:class="{'col-span-3': this.data.solution !== 'utility'}">
                            <DK_Input id="searchbar" @input="searchfilter()" type="text" textPosition="left" value="" :border="true" width="15rem" :placeholder="$t('general.Search') + ' ' + $t('general.Sensors').toLowerCase()"></DK_Input>
                        </div>
                        <div class="w-56">
                            <VueMultiselect v-if="this.data['meters']"
                                v-model="this.data.busIdDevice" :options="Object.keys(this.data['meters'])" :close-on-select="true"
                                :multiple="false" placeholder='Select meter' @select="selectMultiselectMeter"
                                :allow-empty="false" />
                        </div>
                        <div class="flex items-start justify-end">
                            <Link onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')"
                                :href="((originWater == 0) ? route('Water_Readings', { id: this.data.id }) : route('cityReadings', { idDevice: this.data.id }))">

                                <DK_Button color="blue" :fixedSize="true">
                                    {{ this.$t("general.Readings") }}
                                </DK_Button>

                            </Link>
                        </div>
                        <div class="flex items-start justify-end">

                            <DK_Button class="pt-6" color="blue" :fixedSize="true" onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit'); window.history.go(-1)">
                                {{ this.$t("general.Back") }}
                            </DK_Button>

                        </div>
                    </div>
                </div>
                <div v-bind:class="{ 'hidden': !(this.data.RSSI == null && this.data.Battery == null && this.data.dates.length < 1)}" class="flex gap-2 whitespace-nowrap items-baseline">
                    <i class="fa-solid fa-triangle-exclamation" style="font-size:0.8rem; color:rgba(224,191,52,1);"></i>
                    <p class="font-light text-sm text-white-snow flex whitespace-nowrap">
                        {{ this.$t('text.No records were found for the device') }}
                    </p>
                </div>
            </div>

            <div class="grid 2xl:grid-cols-5 grid-cols-4 pt-4 pb-6 gap-6">
                <div class="col-span-1 text-center text-white-snow baltoro-container p-4 h-fit flex justify-between flex-col 2xl:gap-6 gap-4">
                    <div>
                        <p class="text-md text-center text-cyan-text font-light whitespace-nowrap pb-2">
                            {{ this.$t("general." + "Gateway") }}
                        </p>
                        <div class="grid grid-rows-1 pt-1 mb-2">
                            <div class="flex row-span-1 justify-between text-md pt-1 text-white-snow font-light">
                                <div class="text-left" style="margin-top:0.2rem">
                                    <p class="text-gray-light font-semibold">Movistar</p>
                                </div>
                                <div class="text-right">
                                    <!-- Coverage SVG -->
                                    <i v-if="this.data.RSSI <= 110" class="DK-signal-01"
                                        style="font-size:1.1rem; margin-right:0rem; color:#d1d1d1; margin-left:0.5rem; position:relative; top:0%"></i>
                                    <i v-else-if="this.data.RSSI <= 100" class="DK-signal-02"
                                        style="font-size:1.1rem; margin-right:0rem; color:#d1d1d1; margin-left:0.5rem; position:relative; top:0%"></i>
                                    <i v-else-if="this.data.RSSI <= 85" class="DK-signal-03"
                                        style="font-size:1.1rem; margin-right:0rem; color:#d1d1d1; margin-left:0.5rem; position:relative; top:0%"></i>
                                    <i v-else-if="this.data.RSSI <= 70" class="DK-signal-04"
                                        style="font-size:1.1rem; margin-right:0rem; color:#d1d1d1; margin-left:0.5rem; position:relative; top:0%"></i>
                                    <i v-else class="DK-signal-05"
                                        style="font-size:1.1rem; margin-right:0rem; color:#d1d1d1; margin-left:0.5rem; position:relative; top:0%"></i>

                                    <!-- Battery -->
                                    <i v-if="this.data.Battery <= 2900" class="DK-Batt-25 animate-pulse"
                                        style="font-size:1.5rem; color:#d1d1d1; margin-right:0rem;  margin-left:0.5rem; position:relative; top:10%"></i>
                                    <i v-else-if="this.data.Battery <= 3100" class="DK-Batt-50"
                                        style="font-size:1.5rem; color:#d1d1d1; margin-right:0rem; margin-left:0.5rem; position:relative; top:10%"></i>
                                    <i v-else-if="this.data.Battery <= 3300" class="DK-Batt-75"
                                        style="font-size:1.5rem; color:#d1d1d1; margin-right:0rem; margin-left:0.5rem; position:relative; top:10%"></i>
                                    <i v-else class="DK-Batt-100"
                                        style="font-size:1.5rem; margin-right:0rem; color:#d1d1d1; margin-left:0.5rem; position:relative; top:10%"></i>
                                </div>
                            </div>
                        </div>

                        <div class="flex justify-center items-center relative h-[15rem]">
                            <img v-if="this.data.type_name.indexOf('PIPE20XL') != -1" class="2xl:max-h-60 md:max-h-40 pb-6"
                                src="\assets\images\devices\PIPE20XL_perspec.png" />
                            <img v-else-if="this.data.type_name.indexOf('PIPE20L') != -1" class="2xl:max-h-60 md:max-h-40 pb-6"
                                src="\assets\images\devices\PIPE20W_perspec.png" />
                            <img v-else-if="this.data.type_name.indexOf('PIPE20W') != -1" class="2xl:max-h-60 md:max-h-40 pb-6"
                                src="\assets\images\devices\PIPE20W_perspec.png" />
                            <img v-else-if="this.data.type_name.indexOf('PIPE20P') != -1" class="2xl:max-h-60 md:max-h-40 pb-6"
                                src="\assets\images\devices\PIPE20P_perspec.png" />
                            <img v-else-if="this.data.type_name.indexOf('PIPE20') != -1" class="2xl:max-h-60 md:max-h-40 pb-6"
                                src="\assets\images\devices\PIPE20W_perspec.png" />
                            <img v-else class="2xl:max-h-60 md:max-h-40 pb-6"
                                src="\assets\images\devices\PIPE20W_perspec.png" />

                            <p class="text-gray-light font-semibold text-center absolute bottom-0 left-0 right-0 z-50">{{ this.data.type_name.replace(/_/g, " ") + ' - ' + this.data.version_firmware }}</p>
                        </div>

                    </div>

                    <div class="grid gap-0.5">

                        <div class="flex justify-between text-md text-white-snow font-light 2xl:gap-10 gap-4">
                            <p class="whitespace-nowrap text-left text-cyan-text pr-6">{{ this.$t("general." + "Name") }}</p>
                            <DK_Input id="id_gateway_name" type="text" @input="this.GatewayChange()" :value="this.data.name" :border="false" textPosition="right" width="full"/>
                        </div>

                        <div class="flex justify-between text-md text-white-snow font-light 2xl:gap-10 gap-4">
                            <p class="whitespace-nowrap text-left text-cyan-text pr-6">{{ this.$t("general." + "GatewayID") }}</p>
                            <DK_Input type="text" :value="this.data.id" :border="false" textPosition="right" :readonly="true" width="full"/>
                        </div>

                        <div class="flex justify-between text-md text-white-snow font-light 2xl:gap-10 gap-4">
                            <p class="whitespace-nowrap text-left text-cyan-text pr-6">{{ this.$t("general." + "Group") }}</p>
                            <DK_Input type="text" :value="this.data.group_name" :border="false" textPosition="right" :readonly="true" width="full"/>
                        </div>

                    </div>

                    <div class="rounded-md border border-gray-semimedium">
                        <div class="2xl:h-[15rem] h-[12rem] rounded-md" id="map" v-on:click="this.openMapconfig()"/>

                        <JetModal :show="this.Mapconfig" :closeable="false">

                            <p class="text-md text-center text-cyan-text font-light whitespace-nowrap p-2">
                                {{ this.$t("general." + "Edit location") }}
                            </p>

                            <div class="h-[22.5rem] w-[40rem]" id="mapModal"/>

                            <div class="grid grid-cols-3 gap-4 p-2">

                                <div class="flex justify-center text-md py-1 text-white-snow font-light gap-2">
                                    <p class="text-right text-cyan-text">{{ this.$t("general." + "Latitude") }}:</p>
                                    <DK_Input id="id_lat" type="text" @input="this.MapChange()" v-on:keyup="updateLocation()" :value="this.data.GPS_lat" :border="false" textPosition="center" width="6rem"/>
                                </div>

                                <div class="flex justify-center text-md py-1 text-white-snow font-light gap-2">
                                    <p class="text-right text-cyan-text">{{ this.$t("general." + "Longitude") }}:</p>
                                    <DK_Input id="id_lng" type="text" @input="this.MapChange()" v-on:keyup="updateLocation()" :value="this.data.GPS_lng" :border="false" textPosition="center" width="6rem"/>
                                </div>

                                <div class="flex justify-end items-center">
                                    <div class="flex gap-2">

                                        <DK_Button color="blue" :fixedSize="true" :disabled="this.MapChange_var" v-on:click="this.SaveMap()">
                                            {{ this.$t("general.Save") }}
                                        </DK_Button>

                                        <DK_Button color="blue" :fixedSize="true" v-on:click="this.CancelMap()">
                                            {{ this.$t("general.Cancel") }}
                                        </DK_Button>

                                    </div>
                                </div>
                            </div>

                        </JetModal>

                    </div>

                    <div class="flex justify-end items-end gap-4" v-if="this.GatewayChange_var">
                        <div class="flex gap-2">

                            <DK_Button color="blue" :fixedSize="true" v-on:click="this.SaveGateway()">
                                {{ this.$t("general.Save") }}
                            </DK_Button>

                            <DK_Button color="blue" :fixedSize="true" v-on:click="this.CancelGateway()">
                                {{ this.$t("general.Cancel") }}
                            </DK_Button>

                        </div>
                    </div>

                    <div class="h-fit w-full border-t border-gray-semimedium" v-if="this.data.solution == 'utility'"></div>

                    <div class="h-fit w-full flex flex-col gap-4" v-if="this.data.solution == 'utility'">
                        <div class="w-full flex flex-col justify-start gap-x-16 gap-y-4">
                            <div class="flex flex-col justify-start text-md text-white-snow font-light w-full">
                                <p class="whitespace-nowrap text-left text-cyan-text w-full">{{ this.$t("general." + "Service label") }}</p>
                                <div class="flex justify-center w-full">
                                    <div class="gap-2 grid grid-cols-10 mt-2 place-items-center">
                                        <p v-for="(data, index) in this.data.group_service" :key="index"
                                        :style="{ 'background-color': data.color}"
                                        v-on:click="this.updateService(data.id)"
                                        :class="this.getColumnClass(index, data.id)">
                                            {{ data.tag }}
                                        </p>
                                    </div>
                                </div>
                            </div>

                            <div class="flex flex-col justify-start text-md text-white-snow font-light w-full">
                                <p class="whitespace-nowrap text-left text-cyan-text w-full">{{ this.$t("general." + "Sector labels") }}</p>
                                <div class="flex justify-center mt-2 gap-x-2" v-on:click="this.openSectorconfig()">
                                    <div v-for="(data_s, index_s) in this.Sector" :key="index_s" class="flex">
                                        <div v-for="(data_g, index_g) in this.data.group_sector" :key="index_g"
                                            class="inline-flex rounded-md text-white-snow font-light text-base ">
                                            <p v-if="index_s == this.data.group_sector[index_g].id" class="label-profile">
                                                {{ data_g.tag }}
                                            </p>
                                        </div>
                                    </div>
                                    <div v-if="JSON.stringify(this.Sector) == '{}'" class="label-profile opacity-30 hover:opacity-50">
                                        <i class="fa-solid fa-plus" style="font-size:1rem; color:#FFFAFA;"></i>
                                    </div>
                                </div>
                            </div>

                            <JetModal :show="this.Sectorconfig" :closeable="false">
                                <div class="p-4">
                                    <p class="text-cyan-text text-left ml-1">
                                        {{ this.$t("general." + "Sectorization") }}</p>
                                    <div
                                        class="rounded-md border border-gray-semimedium w-full bg-transparent overflow-y-scroll p-2 mt-1 text-gray-light">
                                        <div class="grid grid-cols-4 w-full place-items-center">
                                            <p>{{ this.$t("general." + "Sector") }}</p>
                                            <p>{{ this.$t("general." + "Input") }}</p>
                                            <p>{{ this.$t("general." + "Output") }}</p>
                                            <p>{{ this.$t("general." + "Control") }}</p>
                                        </div>
                                        <div class="border-b border-gray-semimedium mt-1 w-full mb-1"></div>
                                        <div class="h-[15rem] overflow-y-scroll">
                                            <div class="grid grid-cols-4 w-full place-items-center"
                                                v-for="(data, index) in this.data.group_sector" :key="index">
                                                <p>{{ data['name'] }}</p>
                                                <input v-if="this.Sector[data.id] == 'Input'"
                                                    v-on:click="this.changecheck(data['id'], 'Input')"
                                                    class="h-4" type="radio" :id="data['name'] + '_Input'"
                                                    :value="data['name'] + '_Input'" checked />
                                                <input v-else v-on:click="this.changecheck(data['id'], 'Input')"
                                                    class="h-4" type="radio" :id="data['name'] + '_Input'"
                                                    :value="data['name'] + '_Input'" />

                                                <input v-if="this.Sector[data.id] == 'Output'"
                                                    v-on:click="this.changecheck(data['id'], 'Output')"
                                                    class="h-4" type="radio" :id="data['name'] + '_Output'"
                                                    :value="data['name'] + '_Output'" checked />
                                                <input v-else
                                                    v-on:click="this.changecheck(data['id'], 'Output')"
                                                    class="h-4" type="radio" :id="data['name'] + '_Output'"
                                                    :value="data['name'] + '_Output'" />

                                                <input v-if="this.Sector[data.id] == 'Control'"
                                                    v-on:click="this.changecheck(data['id'], 'Control')"
                                                    class="h-4" type="radio" :id="data['name'] + '_Control'"
                                                    :value="data['name'] + '_Control'" checked />
                                                <input v-else
                                                    v-on:click="this.changecheck(data['id'], 'Control')"
                                                    class="h-4" type="radio" :id="data['name'] + '_Control'"
                                                    :value="data['name'] + '_Control'" />

                                            </div>
                                        </div>
                                    </div>
                                    <div class="flex justify-end h-full items-end gap-4 pt-4">
                                        <div class="flex gap-2">

                                            <DK_Button color="blue" :fixedSize="true" v-on:click="this.SaveSectors()" v-if="this.SectorsChange_var">
                                                {{ this.$t("general.Save") }}
                                            </DK_Button>

                                            <DK_Button color="blue" :fixedSize="true" v-on:click="this.CancelSectors()">
                                                {{ this.$t("general.Cancel") }}
                                            </DK_Button>

                                        </div>
                                    </div>
                                </div>
                            </JetModal>

                        </div>

                        <div class="flex justify-end items-end gap-4" v-if="this.LabelsChange_var">
                            <div class="flex gap-2">

                                <DK_Button color="blue" :fixedSize="true" v-on:click="this.SaveLabels()">
                                    {{ this.$t("general.Save") }}
                                </DK_Button>

                                <DK_Button color="blue" :fixedSize="true" v-on:click="this.CancelLabels()">
                                    {{ this.$t("general.Cancel") }}
                                </DK_Button>

                            </div>
                        </div>
                    </div>
                </div>

                <div class="2xl:col-span-4 col-span-3 text-center text-white-snow flex flex-col justify-start gap-4 overflow-y-scroll">

                    <div class="h-full w-full flex flex-col overflow-y-hidden gap-4">

                        <div v-for="(name, sensor) in this.data.names" :key="sensor" class="baltoro-container flex justify-start gap-4 h-[100px]"
                        v-bind:class="{'hidden' : this.visible[sensor] == false}">

                            <div class="flex flex-col justify-between w-fit pl-4 py-2">

                                <!--<div class="flex justify-center items-baseline text-md text-white-snow font-light pb-0.5 gap-4">
                                    <div class="border border-white rounded-full w-6 h-6 grid place-content-center">
                                        <i :class="this.getIconName((this.data.units[sensor] != null ? this.data.units[sensor] : ''), this.data.names[sensor][0])" style="font-size:1rem; color:#FFFAFA;"></i>
                                    </div>-->
                                    <DK_Input :id="'id_sensor_name_' + sensor" type="text" :value="name" :border="false" textPosition="left" width="15rem"/>
                                <!--</div>-->

                                <div class="flex flex-row justify-center items-center text-md text-white-snow font-light pb-0.5 gap-4">

                                    <div class="border border-white rounded-full w-[25px] h-[25px] grid place-content-center aspect-square">
                                        <i :class="this.getIconName((this.data.units[sensor] != null ? this.data.units[sensor] : ''), this.data.names[sensor][0])" style="font-size:1rem; color:#FFFAFA;"></i>
                                    </div>

                                    <div class="flex flex-col w-full">

                                        <div class="flex justify-between text-md text-white-snow font-light">
                                            <p class="whitespace-nowrap text-left text-cyan-text">{{ this.$t("general." + "Unit") }}</p>
                                            <DK_Input :id="'id_sensor_unit_' + sensor" type="text" :value="(this.data.units[sensor] != null ? this.data.units[sensor] : '')" :border="false" textPosition="right" width="4rem"/>
                                        </div>

                                        <div class="flex justify-between text-md text-white-snow font-light">
                                            <p class="whitespace-nowrap text-left text-cyan-text">{{ this.$t("general." + "Decimals") }}</p>
                                            <DK_Input :id="'id_sensor_decimals_' + sensor" type="text" :value="this.data.decimals[sensor]" :border="false" textPosition="right" width="4rem"/>
                                        </div>

                                    </div>
                                </div>
                            </div>

                            <div class="h-full w-fit border-r border-gray-semimedium pl-4 mr-4"></div>

                            <div class="flex flex-col justify-center">
                                <!--<p class="whitespace-nowrap text-center text-cyan-text w-full">{{ this.$t("general." + "Last sent") }}</p>-->
                                <div class="bg-cyan-opa w-[5rem] h-[5rem] flex justify-center items-center text-center rounded-lg">
                                    <p :id="'id_counter_' + sensor" class="text-white-snow h-fit text-lg"></p>
                                    <p class="text-white-snow h-fit text-lg">&nbsp;{{ (this.data.units[sensor] != null ? this.data.units[sensor] : '') }}</p>
                                </div>
                            </div>

                            <div class="h-full w-fit border-r border-gray-semimedium pl-4 mr-4"></div>

                            <div class="h-[99px] w-full pr-4" :id="'id_chart_' + sensor"></div>

                        </div>
                    </div>
                </div>
            </div>
        </div>

        <div v-else style="height: calc(100vh - 4.75rem);" class="bg-darkblue-background z-0 flex flex-col gap-4 overflow-x-hidden cursor-default">
            <div class="w-full flex flex-col justify-center items-start pt-2 pb-1 gap-2">
                <div class="w-full flex flex-row justify-between items-center px-3 h-[3.25rem]">
                    <div class="w-full flex flex-col justify-start">
                        <div class="flex flex-row justify-start">
                            <p class="text-white-snow font-light text-2xl text-left">{{ this.$t('general.Profile Information') }}</p>
                        </div>
                    </div>
                    <div class="flex justify-end gap-2">
                        <div class="w-56">
                            <VueMultiselect v-if="this.data['meters']"
                                v-model="this.data.busIdDevice" :options="Object.keys(this.data['meters'])" :close-on-select="true"
                                :multiple="false" placeholder='Select meter' @select="selectMultiselectMeter"
                                :allow-empty="false" />
                        </div>
                        <div class="flex items-center justify-center">
                            <Link onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')"
                                :href="((originWater == 0) ? route('Water_Readings', { id: this.data.id }) : route('cityReadings', { idDevice: this.data.id }))">
                                <button type="button"
                                    class="text-white-snow button-blue hover:bg-blue-800 focus:ring-4 focus:outline-none focus:ring-blue-300 font-medium rounded-lg text-sm p-1.5 text-center inline-flex items-center dark:bg-blue-600 dark:hover:bg-blue-700 dark:focus:ring-blue-800">
                                    <i class="fa-solid fa-chart-column" style="font-size:0.75rem; color:#FFFAFA;"></i>
                                </button>
                            </Link>
                        </div>
                        <div class="flex items-center justify-center">
                            <Link onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit'); window.history.go(-1)">
                                <button type="button" class="text-white-snow button-blue font-medium rounded-lg text-sm p-1.5 text-center inline-flex items-center">
                                    <i class="fa-solid fa-arrow-left" style="font-size:0.75rem; color:#FFFAFA;"></i>
                                </button>
                            </Link>
                        </div>
                    </div>
                </div>

                <div v-bind:class="{ 'hidden': !(this.data.RSSI == null && this.data.Battery == null)}" class="flex gap-2 whitespace-nowrap items-baseline">
                    <i class="fa-solid fa-triangle-exclamation" style="font-size:0.8rem; color:rgba(224,191,52,1);"></i>
                    <p class="font-light text-sm text-white-snow flex whitespace-nowrap">
                        {{ this.$t('text.No records were found for the device') }}
                    </p>
                </div>

                <div class="w-full flex overflow-x-auto snap-mandatory snap-x pb-2 gap-4 px-3 overflow-y-hidden">
                    <div class="snap-center col-span-1 text-center text-white-snow baltoro-container shrink-0 p-2 h-fit w-full flex justify-between flex-col 2xl:gap-10 gap-2">
                        <div>
                            <p class="text-cyan-text font-light text-lg mb-2 whitespace-nowrap w-full text-center">{{ this.$t("general." + "Gateway") }}</p>

                            <div class="grid grid-rows-1">
                                <div class="flex row-span-1 justify-between text-md pt-1 text-white-snow font-light">
                                    <div class="text-left" style="margin-top:0.2rem">
                                        <p class="text-gray-light font-semibold">Movistar</p>
                                    </div>
                                    <div class="text-right">
                                        <!-- Coverage SVG -->
                                        <i v-if="this.data.RSSI <= 110" class="DK-signal-01"
                                            style="font-size:1.1rem; margin-right:0rem; color:#d1d1d1; margin-left:0.5rem; position:relative; top:0%"></i>
                                        <i v-else-if="this.data.RSSI <= 100" class="DK-signal-02"
                                            style="font-size:1.1rem; margin-right:0rem; color:#d1d1d1; margin-left:0.5rem; position:relative; top:0%"></i>
                                        <i v-else-if="this.data.RSSI <= 85" class="DK-signal-03"
                                            style="font-size:1.1rem; margin-right:0rem; color:#d1d1d1; margin-left:0.5rem; position:relative; top:0%"></i>
                                        <i v-else-if="this.data.RSSI <= 70" class="DK-signal-04"
                                            style="font-size:1.1rem; margin-right:0rem; color:#d1d1d1; margin-left:0.5rem; position:relative; top:0%"></i>
                                        <i v-else class="DK-signal-05"
                                            style="font-size:1.1rem; margin-right:0rem; color:#d1d1d1; margin-left:0.5rem; position:relative; top:0%"></i>

                                        <!-- Battery -->
                                        <i v-if="this.data.Battery <= 2900" class="DK-Batt-25 animate-pulse"
                                            style="font-size:1.5rem; color:#d1d1d1; margin-right:0rem;  margin-left:0.5rem; position:relative; top:10%"></i>
                                        <i v-else-if="this.data.Battery <= 3100" class="DK-Batt-50"
                                            style="font-size:1.5rem; color:#d1d1d1; margin-right:0rem; margin-left:0.5rem; position:relative; top:10%"></i>
                                        <i v-else-if="this.data.Battery <= 3300" class="DK-Batt-75"
                                            style="font-size:1.5rem; color:#d1d1d1; margin-right:0rem; margin-left:0.5rem; position:relative; top:10%"></i>
                                        <i v-else class="DK-Batt-100"
                                            style="font-size:1.5rem; margin-right:0rem; color:#d1d1d1; margin-left:0.5rem; position:relative; top:10%"></i>
                                    </div>
                                </div>
                            </div>

                            <div class="flex justify-center items-center relative h-[15rem]" v-bind:class="{'h-[12rem]' : this.screen_width <= 768}">
                                <img v-if="this.data.type_name.indexOf('PIPE20XL') != -1" class="2xl:max-h-60 md:max-h-40" v-bind:class="{'h-40' : this.screen_width <= 768}"
                                    src="\assets\images\devices\PIPE20XL_perspec.png" />
                                <img v-else-if="this.data.type_name.indexOf('PIPE20L') != -1" class="2xl:max-h-60 md:max-h-40" v-bind:class="{'h-40' : this.screen_width <= 768}"
                                    src="\assets\images\devices\PIPE20W_perspec.png" />
                                <img v-else-if="this.data.type_name.indexOf('PIPE20W') != -1" class="2xl:max-h-60 md:max-h-40" v-bind:class="{'h-40' : this.screen_width <= 768}"
                                    src="\assets\images\devices\PIPE20W_perspec.png" />
                                <img v-else-if="this.data.type_name.indexOf('PIPE20P') != -1" class="2xl:max-h-60 md:max-h-40" v-bind:class="{'h-40' : this.screen_width <= 768}"
                                    src="\assets\images\devices\PIPE20P_perspec.png" />
                                <img v-else-if="this.data.type_name.indexOf('PIPE20') != -1" class="2xl:max-h-60 md:max-h-40" v-bind:class="{'h-40' : this.screen_width <= 768}"
                                    src="\assets\images\devices\PIPE20W_perspec.png" />
                                <img v-else class="2xl:max-h-60 md:max-h-40" v-bind:class="{'h-40' : this.screen_width <= 768}"
                                    src="\assets\images\devices\PIPE20W_perspec.png" />

                                <p class="text-gray-light font-semibold text-center absolute bottom-0 left-0 right-0 z-50">{{ this.data.type_name.replace(/_/g, " ") + ' - ' + this.data.version_firmware }}</p>
                            </div>

                        </div>

                        <div class="grid">

                            <div class="flex justify-between text-md text-white-snow font-light">
                                <p class="whitespace-nowrap text-left text-cyan-text 2xl:pr-6">{{ this.$t("general." + "Name") }}</p>
                                <DK_Input id="id_gateway_name" type="text" @input="this.GatewayChange()" :value="this.data.name" :border="false" textPosition="right"/>
                            </div>
                            <div class="flex justify-between text-md text-white-snow font-light">
                                <p class="whitespace-nowrap text-left text-cyan-text 2xl:pr-6">{{ this.$t("general." + "GatewayID") }}</p>
                                <DK_Input width="7rem" type="text" :value="this.data.id" :border="false" textPosition="right" :readonly="true"/>
                            </div>
                            <div class="flex justify-between text-md text-white-snow font-light">
                                <p class="whitespace-nowrap text-left text-cyan-text 2xl:pr-6">{{ this.$t("general." + "Group") }}</p>
                                <DK_Input type="text" :value="this.data.group_name" :border="false" textPosition="right" :readonly="true"/>
                            </div>
                        </div>

                        <div class="rounded-md border border-gray-semimedium">
                            <div class="2xl:h-[15rem] h-[12rem] rounded-md" id="map" v-on:click="this.openMapconfig()"/>

                                <JetModal :show="this.Mapconfig" :closeable="false">

                                    <div class="w-full h-max flex flex-row justify-between items-center px-4 py-2 ">
                                        <div class="w-full flex flex-col justify-start">
                                            <div class="flex flex-row justify-start">
                                                <p class="text-white-snow font-light text-2xl text-left">{{ this.$t('general.Edit location') }}</p>
                                            </div>
                                        </div>
                                        <div class="flex justify-end gap-2 h-full items-start">
                                            <div class="flex items-center justify-center" v-on:click="this.CancelMap()">
                                                <i class="fa-solid fa-xmark" style="font-size:1rem; color:rgba(200, 200, 200, 0.9); "></i>
                                            </div>
                                        </div>
                                    </div>

                                    <div class="h-[22.5rem] w-full" id="mapModal"/>

                                    <div class="flex justify-between items-center gap-x-[2.5rem] p-2 w-[90vw]">

                                        <div class="grid grid-cols-2 w-[10rem] text-sm font-light">
                                            <p class="text-left w-fit text-cyan-text">{{ this.$t("general." + "Latitude") }}:</p>
                                            <DK_Input id="id_lat" type="text" width="6rem" :value="this.data.GPS_lat" :border="false" textPosition="center" v-on:keyup="updateLocation()"/>
                                            <p class="text-left w-fit text-cyan-text">{{ this.$t("general." + "Longitude") }}:</p>
                                            <DK_Input id="id_lng" type="text" width="6rem" :value="this.data.GPS_lng" :border="false" textPosition="center" v-on:keyup="updateLocation()"/>
                                        </div>


                                        <div class="flex justify-end items-center">
                                            <div class="flex gap-2">

                                                <DK_Button color="blue" :fixedSize="true" :disabled="this.MapChange_var" v-on:click="this.SaveMap()">
                                                    {{ this.$t("general.Save") }}
                                                </DK_Button>

                                            </div>
                                        </div>
                                    </div>

                                </JetModal>
                            </div>

                        <div class="flex justify-end items-end gap-4" v-if="this.GatewayChange_var">
                            <div class="flex gap-2">

                                <DK_Button color="blue" :fixedSize="true" v-on:click="this.SaveGateway()">
                                    {{ this.$t("general.Save") }}
                                </DK_Button>

                                <DK_Button color="blue" :fixedSize="true" v-on:click="this.CancelGateway()">
                                    {{ this.$t("general.Cancel") }}
                                </DK_Button>

                            </div>
                        </div>
                    </div>

                    <div class="snap-center col-span-1 text-center text-white-snow shrink-0 h-fit w-full flex justify-between flex-col 2xl:gap-10 gap-2">

                        <div class="text-center text-white-snow baltoro-container p-2 h-fit w-full flex justify-between flex-col 2xl:gap-10 gap-4" v-if="this.data.solution == 'utility'">

                            <!--<p class="text-md text-center text-cyan-text font-light whitespace-nowrap">
                                {{ this.$t("general." + "Labels") }}
                            </p>-->

                            <div class="w-full flex flex-col justify-start gap-2">
                                <div class="flex flex-col justify-center text-md text-white-snow font-light w-full">
                                    <p class="whitespace-nowrap text-center text-cyan-text w-full">{{ this.$t("general." + "Service label") }}</p>
                                    <div class="flex justify-center">
                                        <div class="gap-2 grid grid-cols-10 mt-2 place-items-center">
                                            <p v-for="(data, index) in this.data.group_service" :key="index"
                                            :style="{ 'background-color': data.color}"
                                            v-on:click="this.updateService(data.id)"
                                            :class="this.getColumnClass(index, data.id)">
                                                {{ data.tag }}
                                            </p>
                                        </div>
                                    </div>
                                </div>

                                <div class="flex flex-col justify-center text-md text-white-snow font-light w-full">
                                    <p class="whitespace-nowrap text-center text-cyan-text w-full">{{ this.$t("general." + "Sector labels") }}</p>
                                    <div class="flex justify-center mt-2 gap-x-2" v-on:click="this.openSectorconfig()">
                                        <div v-for="(data_s, index_s) in this.Sector" :key="index_s" class="flex">
                                            <div v-for="(data_g, index_g) in this.data.group_sector" :key="index_g"
                                                class="inline-flex rounded-md text-white-snow font-light text-base ">
                                                <p v-if="index_s == this.data.group_sector[index_g].id" class="label-profile">
                                                    {{ data_g.tag }}
                                                </p>
                                            </div>
                                        </div>
                                        <div v-if="JSON.stringify(this.Sector) == '{}'" class="label-profile opacity-30 hover:opacity-50">
                                            <i class="fa-solid fa-plus" style="font-size:1rem; color:#FFFAFA;"></i>
                                        </div>
                                    </div>
                                </div>

                                <JetModal :show="this.Sectorconfig" :closeable="false">
                                    <div class="p-4">
                                        <p class="text-cyan-text text-left ml-1">
                                            {{ this.$t("general." + "Sectorization") }}</p>
                                        <div
                                            class="rounded-md border border-gray-semimedium w-full bg-transparent overflow-y-scroll p-2 mt-1 text-gray-light">
                                            <div class="grid grid-cols-4 w-full place-items-center">
                                                <p>{{ this.$t("general." + "Sector") }}</p>
                                                <p>{{ this.$t("general." + "Input") }}</p>
                                                <p>{{ this.$t("general." + "Output") }}</p>
                                                <p>{{ this.$t("general." + "Control") }}</p>
                                            </div>
                                            <div class="border-b border-gray-semimedium mt-1 w-full mb-1"></div>
                                            <div class="h-[15rem] overflow-y-scroll">
                                                <div class="grid grid-cols-4 w-full place-items-center"
                                                    v-for="(data, index) in this.data.group_sector" :key="index">
                                                    <p>{{ data['name'] }}</p>
                                                    <input v-if="this.Sector[data.id] == 'Input'"
                                                        v-on:click="this.changecheck(data['id'], 'Input')"
                                                        class="h-4" type="radio" :id="data['name'] + '_Input'"
                                                        :value="data['name'] + '_Input'" checked />
                                                    <input v-else v-on:click="this.changecheck(data['id'], 'Input')"
                                                        class="h-4" type="radio" :id="data['name'] + '_Input'"
                                                        :value="data['name'] + '_Input'" />

                                                    <input v-if="this.Sector[data.id] == 'Output'"
                                                        v-on:click="this.changecheck(data['id'], 'Output')"
                                                        class="h-4" type="radio" :id="data['name'] + '_Output'"
                                                        :value="data['name'] + '_Output'" checked />
                                                    <input v-else
                                                        v-on:click="this.changecheck(data['id'], 'Output')"
                                                        class="h-4" type="radio" :id="data['name'] + '_Output'"
                                                        :value="data['name'] + '_Output'" />

                                                    <input v-if="this.Sector[data.id] == 'Control'"
                                                        v-on:click="this.changecheck(data['id'], 'Control')"
                                                        class="h-4" type="radio" :id="data['name'] + '_Control'"
                                                        :value="data['name'] + '_Control'" checked />
                                                    <input v-else
                                                        v-on:click="this.changecheck(data['id'], 'Control')"
                                                        class="h-4" type="radio" :id="data['name'] + '_Control'"
                                                        :value="data['name'] + '_Control'" />

                                                </div>
                                            </div>
                                        </div>
                                        <div class="flex justify-end h-full items-end gap-4 pt-4">
                                            <div class="flex gap-2">

                                                <DK_Button color="blue" :fixedSize="true" v-on:click="this.SaveSectors()" v-if="this.SectorsChange_var">
                                                    {{ this.$t("general.Save") }}
                                                </DK_Button>

                                                <DK_Button color="blue" :fixedSize="true" v-on:click="this.CancelSectors()">
                                                    {{ this.$t("general.Cancel") }}
                                                </DK_Button>

                                            </div>
                                        </div>
                                    </div>
                                </JetModal>

                            </div>

                            <div class="flex justify-center items-end gap-4" v-if="this.LabelsChange_var">
                                <div class="flex gap-2">

                                    <DK_Button color="blue" :fixedSize="true" v-on:click="this.SaveLabels()">
                                        {{ this.$t("general.Save") }}
                                    </DK_Button>

                                    <DK_Button color="blue" :fixedSize="true" v-on:click="this.CancelLabels()">
                                        {{ this.$t("general.Cancel") }}
                                    </DK_Button>

                                </div>
                            </div>
                        </div>

                        <div v-for="(name, sensor) in this.data.names" :key="sensor" class="text-center text-white-snow baltoro-container h-fit w-full flex justify-start items-center flex-col 2xl:gap-10 gap-2 p-2"
                            v-bind:class="{'hidden' : this.visible[sensor] == false}">

                            <!--<div class="flex flex-col justify-between w-full">-->
                            <div class="grid grid-cols-3 w-full">

                                <div class="flex flex-col justify-between w-fit col-span-2">

                                    <div class="flex justify-start items-baseline text-md text-white-snow font-light pb-0.5 gap-4 w-full">
                                        <div class="border border-white rounded-full w-6 h-6 grid place-content-center">
                                            <i :class="this.getIconName((this.data.units[sensor] != null ? this.data.units[sensor] : ''), this.data.names[sensor][0])" style="font-size:1rem; color:#FFFAFA;"></i>
                                        </div>
                                        <DK_Input :id="'id_sensor_name_' + sensor" type="text" :value="name" :border="false" textPosition="left" width="10rem"/>
                                    </div>

                                    <div class="flex flex-col">

                                        <div class="flex justify-between text-md text-white-snow font-light">
                                            <p class="whitespace-nowrap text-left text-cyan-text">{{ this.$t("general." + "Unit") }}</p>
                                            <DK_Input :id="'id_sensor_unit_' + sensor" type="text" :value="(this.data.units[sensor] != null ? this.data.units[sensor] : '')" :border="false" textPosition="right" width="4rem"/>
                                        </div>

                                        <div class="flex justify-between text-md text-white-snow font-light">
                                            <p class="whitespace-nowrap text-left text-cyan-text">{{ this.$t("general." + "Decimals") }}</p>
                                            <DK_Input :id="'id_sensor_decimals_' + sensor" type="text" :value="this.data.decimals[sensor]" :border="false" textPosition="right" width="4rem"/>
                                        </div>

                                    </div>

                                </div>

                                <div class="flex justify-end w-full">
                                    <!--<p class="whitespace-nowrap text-center text-cyan-text w-full">{{ this.$t("general." + "Last sent") }}</p>-->
                                    <div class="bg-cyan-opa w-[5rem] h-[5rem] flex justify-center items-center text-center rounded-lg">
                                        <p :id="'id_counter_' + sensor" class="text-white-snow h-fit text-lg"></p>
                                        <p class="text-white-snow h-fit text-lg">&nbsp;{{ (this.data.units[sensor] != null ? this.data.units[sensor] : '') }}</p>
                                    </div>
                                </div>

                            </div>



                            <div v-if="false" class="h-[8rem] w-full" :id="'id_chart_' + sensor"></div>

                        </div>
                    </div>

                </div>
            </div>
        </div>
    </AppLayout>
</template>

<script>
export default {
    props: [ 'data', 'user'],

    data() {
        return {
            Back: localStorage.getItem('Back'),
            Mapconfig: false,
            GPS_lat: this.data.GPS_lat,
            GPS_lng: this.data.GPS_lng,
            mapModal: undefined,
            sensor_index: 0,
            screen_width: 0,
            visible: {},
            str_img: (this.data.solution !== 'utility') ? "../assets/images/markers/marker_" + this.data.solution + ".png" : "../assets/images/markers/" + this.getMarker(this.data.gateway.service_name) + ".png",
            GatewayChange_var: false,
            Highcharts: require('highcharts'),
            service_id: (this.data.solution !== 'utility') ? null : this.data.Idservice,
            Sector: (this.data.solution !== 'utility') ? null : { ...this.data.Sector },
            Sectorconfig: (this.data.solution !== 'utility') ? null : false,
            LabelsChange_var: (this.data.solution !== 'utility') ? null : false,
            SectorsChange_var: (this.data.solution !== 'utility') ? null : false,
            MapChange_var: false,
            originWater: ((window.location.origin.indexOf('localhost:8000') !== -1 || window.location.origin.indexOf('water.baltoro.app') !== -1) ? 0 : (
                window.location.origin.indexOf('localhost:8001') !== -1 || window.location.origin.indexOf('city.baltoro.app') !== -1 || window.location.origin.indexOf('new.baltoro.app') !== -1) ? 1 : 2),
            charts: new Array(),

        }
    },

    beforeMount() {

        this.screen_width = window.screen.width;

        Object.keys(this.data.names).forEach( (sensor) => {
            this.visible[sensor] = true
        })
    },

    mounted() {

        window.emitter.emit('changeLoaderStatus', false, 'orbit')

        // MAPBOX ACCESS TOKEN
        mapboxgl.accessToken = 'pk.eyJ1IjoiZGF0YWtvcnVtLWRldmVsb3AiLCJhIjoiY2w0ODhqOXc2MDR1MjNjbzJ2YnZkdjNhYSJ9.pVPMnmkwOuF4DonlbNkkEw';

        this.rechargePage();

    },

    methods: {

        rechargePage() {

            // creating map
            const map = new mapboxgl.Map({
            attributionControl: false,
            container: "map",
            style: 'mapbox://styles/datakorum-develop/cl4cu370w000v15tal53sxn9v',
            center: [this.data.GPS_lng, this.data.GPS_lat],
            zoom: 15,
            pitch: 50,
            bearing: 0,
            interactive: false
            });

            let img = document.createElement('img');
            img.src = this.str_img;

            let markerElement = document.createElement('div')
            markerElement.appendChild(img)

            new mapboxgl.Marker({ element: markerElement })
                .setLngLat([this.data.GPS_lng, this.data.GPS_lat])
                .addTo(map);

            const Highcharts = require('highcharts');
            require('highcharts/highcharts-more')(Highcharts);

            const Chart = {
                chart: {
                    zoomType: 'x',
                    backgroundColor: 'transparent',
                    animation: {
                        duration: 150
                    },
                    resetZoomButton: {
                        position: {
                            align: 'left',
                            verticalAlign: 'top',
                            x: 0,
                            y: 2.5
                        },
                        theme: {
                            r: 5.6,
                        }
                    },
                },
                accessibility: {
                    enabled: false
                },
                title: {
                    text: ''
                },
                xAxis: {
                    visible: false,
                    labels: {
                        style: {
                            color: 'rgba(200, 200, 200, 0.9)',
                            opacity: 0.7,
                        }
                    },
                    type: "datetime",
                    dateTimeLabelFormats: {
                        week: '%m-%d',
                        month: '%Y-%m',
                        year: '%Y'
                    },
                },
                yAxis: [{
                    opposite: true,
                    title: {
                    text: ''
                    },
                    labels: {
                        formatter: function () {
                            return this.pos + '  ' + this.chart.userOptions.series[0].tooltip.valueSuffix
                        },
                        style: {
                            color: 'rgba(200, 200, 200, 0.9)',
                            opacity: 0.7,
                        }
                    },
                    visible: true,
                    endOnTick: false
                }],
                plotOptions: {
                    column: {
                        borderWidth: 0
                    }
                },
                exporting: {
                    enabled: false
                },
                credits: {
                    enabled: false
                },
                legend: {
                    enabled: false,
                },

                tooltip: {
                    shared: true,
                    split: false,
                    backgroundColor: 'rgba(7,82,103,0.95)',
                    borderRadius: 12,
                    borderWidth: 1,
                    borderColor: 'rgba(250, 250, 250, 0.65)',
                    padding: 6,
                    formatter: function () {

                        function formatDate(epochMs) {
                            const fecha = new Date(epochMs);
                            const year = fecha.getFullYear();
                            const month = String(fecha.getMonth() + 1).padStart(2, '0');
                            const day = String(fecha.getDate()).padStart(2, '0');
                            const hours = String(fecha.getHours()).padStart(2, '0');
                            const minutes = String(fecha.getMinutes()).padStart(2, '0');
                            const seconds = String(fecha.getSeconds()).padStart(2, '0');

                            return `${year}/${month}/${day} ${hours}:${minutes}:${seconds}`;
                        }


                        var s = '<b>' + '<p style="font-size:12px; line-height: 12px; font-weight: 300; color:rgba(250, 250, 250, 0.95)">' + formatDate(this.x) + ' → </p>'; //
                        $.each(this.points, function () {
                            s += '<p style="font-size:12px; line-height: 12px; font-weight: 400; color:' + this.series.color + '">' + this.y.toFixed(3) +
                                ' ' + this.series.userOptions.tooltip.valueSuffix + '</p><br/>';
                        });


                        return s;
                    },
                },
            };

            let max = new Array();
            let min = new Array();
            let ChartData = new Array();
            let SensorArray = new Array();

            Object.keys(this.data.names).forEach( (sensor, index) => {

                SensorArray[index] = sensor;

                ChartData[index] = new Array()

                if(this.data.dates){

                    this.data.dates.forEach( (date, index_d) => {

                        let value = parseFloat(this.data.data[sensor][index_d])

                        if(min[index] == undefined || min[index] > value) min[index] = value;

                        if(max[index] == undefined || max[index] < value) max[index] = value;

                        ChartData[index][index_d] = [
                            (new Date(date)).getTime(),
                            value,
                        ]

                    })

                    if(min[index] == max[index]){
                        min[index] = min[index] - 1
                    }

                    ChartData[index].reverse();
                }
            })

            for(let i=0 ; i<ChartData.length ; i++){

                let tempChart = {...Chart}

                tempChart.yAxis[0].tickPositions = [min[i], max[i]];

                tempChart.series = [{
                    name: this.$t("general." + "Data period"),
                    type: 'spline',
                    data: ChartData[i],
                    //opacity: 0.5,
                    color: 'rgba(5,255,243,1)',
                    marker: {
                        enabled: false
                    },
                    tooltip: {
                        valueSuffix: (this.data.units[SensorArray[i]] != null ? this.data.units[SensorArray[i]] : '')
                    }
                }];

                if(document.getElementById('id_counter_' + SensorArray[i]) && typeof ChartData[i][ChartData[i].length - 1 ][1] != 'undefined'){
                    document.getElementById('id_counter_' + SensorArray[i]).innerText = ChartData[i][ChartData[i].length - 1 ][1];
                }

                Highcharts.chart('id_chart_' + SensorArray[i], tempChart);
            }
        },

        searchfilter() {
            let i = 0;

            var input,
            filter,
            Name,
            Unit,
            txtValueName,
            txtValueUnit;

            //text input
            input = document.getElementById("searchbar");

            //text to filter
            filter = input.value.toUpperCase();

            Object.keys(this.data.names).forEach( (sensor) => {

                // name search
                Name = this.data.names[sensor];
                txtValueName = Name.toString();

                // unit search
                Unit = (this.data.units[sensor] != null ? this.data.units[sensor] : '');
                txtValueUnit = Unit.toString();

                if (filter != "") {
                    if (
                    txtValueName.toUpperCase().indexOf(filter) > -1 ||
                    txtValueUnit.toUpperCase().indexOf(filter) > -1
                    ) {
                        this.visible[sensor] = true
                    } else {
                        this.visible[sensor] = false
                    }
                } else {
                    this.visible[sensor] = true
                }
            });

        },

        selectMultiselectMeter: function (item) {
            window.emitter.emit('changeLoaderStatus', true, 'orbit')
            window.location.href = window.location.origin + '/profile/' + this.data.id + '/' + item
        },

        getIconName(unit, letter){

            let icon;

            switch(unit){
                case 'ºC': icon = 'DK-temperatura'; break;
                case 'V': icon = 'DK-voltaje'; break;
                case 'bar': icon = 'DK-presion'; break;
                case '%': icon = 'DK-humedad'; break;
                //case 'A': icon = ''; break;
                //case 'Hz': icon = ''; break;
                //case 'Hz': icon = ''; break;
                default: icon = 'fa-solid fa-' + letter.toLowerCase();
            }

            return icon;
        },

        SaveSectors(){
            this.Sectorconfig = false;
            this.LabelsChange();
        },

        CancelSectors(){
            this.Sector = { ...this.data.Sector };
            this.Sectorconfig = false;
            this.LabelsChange();
        },

        LabelsChange(){

            let bool = false;

            if(JSON.stringify(this.Sector) == '{}'){
                if(
                    this.service_id != this.data.Idservice ||
                    this.data.Sector.length != 0
                ){
                    bool = true;
                }
            }else if(
                this.service_id != this.data.Idservice ||
                JSON.stringify(this.Sector) != JSON.stringify(this.data.Sector)
            ){
                bool = true;
            }

            this.LabelsChange_var = bool;

        },

        SaveLabels() {

            const data = {
                sector: this.Sector,
                idservice: this.service_id
            };

            window.emitter.emit('changeLoaderStatus', true, 'orbit')

            axios({
                method: 'put',
                url: window.location.origin + '/api/meter/edit/' + this.user.id + '/' + this.data.id + '/' + 0,
                headers: {
                    'Accept': 'application/json',
                    'Content-Type': 'application/json',
                    'Authorization': 'Bearer ' + this.user.token
                },
                data: data
            })
            .then((response) => {
                this.data.Idservice = data.idservice;
                this.data.Sector = {...data.sector};

                this.service_id = this.data.Idservice;
                this.Sector = { ...this.data.Sector };

                this.LabelsChange();

                window.emitter.emit('changeLoaderStatus', false, 'orbit')

            })
            .catch((error) => {
                window.emitter.emit('changeLoaderStatus', false, 'orbit')

                if(error.response && error.response.status && error.response.status == 429){
                  window.alert( this.$t('text.Api attempts'));
                }else{
                  return "Failed!", error;
                }

              });
            },

        CancelLabels() {

            this.service_id = this.data.Idservice;
            this.Sector = { ...this.data.Sector };

            this.LabelsChange()
        },

        openSectorconfig() {
            this.Sectorconfig = true;
        },

        updateService(id) {
            this.service_id = id;
            this.LabelsChange()
        },

        getServiceColor(){
            let color;

            this.data.group_service.forEach( (service, index) => {
                if(service.id == this.service_id){
                    color = service.color;
                }
            } )

            return color;
        },

        getServiceName(){
            let name;

            this.data.group_service.forEach( (service, index) => {
                if(service.id == this.service_id){
                    name = service.name;
                }
            } )

            return name;
        },

        changecheck(sector_id, s_function) {

            for (var index = 0; index < this.data.group_sector.length; index++) {
                if (this.data.group_sector[index].id == sector_id) {
                    if (document.getElementById(this.data.group_sector[index].name + '_' + this.Sector[sector_id])) {
                        document.getElementById(this.data.group_sector[index].name + '_' + this.Sector[sector_id]).checked = false;
                    }
                    if (s_function != this.Sector[sector_id]) {
                        this.Sector[sector_id] = s_function;
                    } else {
                        delete this.Sector[sector_id];
                    }
                }
            }

            if(JSON.stringify(this.Sector) != JSON.stringify(this.data.Sector)) {
                this.SectorsChange_var = true
            } else {
                this.SectorsChange_var = false
            }

        },

        MapChange(){

            let bool = false;
            var numsFilter = /^-?\d+(\.\d+)?$/;
            var latValue = parseFloat(document.getElementById('id_lat').value);
            var lngValue = parseFloat(document.getElementById('id_lng').value);

            if (
                !(document.getElementById('id_lat').value).length > 0 || !(document.getElementById('id_lng').value).length > 0
            ){
                bool = true;
            }

            if(!numsFilter.test(document.getElementById('id_lat').value) || !numsFilter.test(document.getElementById('id_lng').value)){

                bool = true;
            } else if( !(latValue >= -90 && latValue <= 90) || !(lngValue >= -90 && lngValue <= 90)){

                bool = true;
            }

            this.MapChange_var = bool;
        },

        getColumnClass(index, id) {

            let colStart;

            if(this.data.group_service.length <= 5 || this.data.group_service.length === 10){
                colStart = index * 2 + 1
            } else if(this.data.group_service.length > 5 && this.data.group_service.length < 10 && this.data.group_service.length % 2 === 1){

                if(this.data.group_service.length == 7){
                    if(index < 4){
                        colStart = index * 2 + 2
                    }else{
                        colStart = (index - 4) * 2 + 3
                    }
                }else if(this.data.group_service.length == 9) {
                    if(index < 5){
                        colStart = index * 2 + 1
                    }else{
                        colStart = (index - 5) * 2 + 2
                    }
                }

            } else if(this.data.group_service.length > 5 && this.data.group_service.length < 10 && this.data.group_service.length % 2 === 0){

                if(this.data.group_service.length == 6){


                    if(index < 3){
                        colStart = index * 2 + 3
                    }else{
                        colStart = (index - 3) * 2 + 3
                    }

                }else if(this.data.group_service.length == 8) {

                    if(index < 4){
                        colStart = index * 2 + 2
                    }else{
                        colStart = (index - 4) * 2 + 2
                    }
                }

            }


            var temp = `col-start-${colStart} label-profile col-span-2`;

            if(this.service_id != id){
                temp += '  opacity-30 hover:opacity-50';
            }

            return temp;
        },

        GatewayChange(){

            let bool = false;
            if(
                document.getElementById('id_gateway_name').value != this.data.name
            ){
                bool = true;
            }

            this.GatewayChange_var = bool;
        },

        /*getSensorsClass(length) {

            let ColNum, RowNum;

            if((this.esPrimo(length) || length == 1) && length <= 7){
                ColNum = 1;
                RowNum = length;
            } else if(length % 3 == 0 && length != 6){
                ColNum = 3;
                RowNum = length / 3;
            } else if(length % 2 == 0){
                ColNum = 2;
                RowNum = length / 2;
            } else {
                ColNum = 1;
            }

            var temp = `grid-cols-${ColNum} `;

            if(RowNum != undefined){
                temp += `grid-rows-${RowNum} `;
            }

            return temp;
        },

        esPrimo(numero) {
            if (numero <= 1) {
                return false;
            }

            for (let i = 2; i < numero; i++) {
                if (numero % i === 0) {
                    return false;
                }
            }

            return true;
        }, */

        switchSensor(index){
            this.sensor_index = index
        },

        updateLocation(){

            this.data.GPS_lat = document.getElementById('id_lat').value
            this.data.GPS_lng = document.getElementById('id_lng').value

            this.mapModal.flyTo({
                center: [this.data.GPS_lng, this.data.GPS_lat],
                essential: true,
            });

            // eliminar todos los marcadores existentes
            this.markers.forEach(marker => marker.remove());
            this.markers = [];

            let img = document.createElement('img');
            img.src = this.str_img;

            let markerElement = document.createElement('div')
            markerElement.appendChild(img)

            this.markers.push(new mapboxgl.Marker({ element: markerElement })
                .setLngLat([this.data.GPS_lng, this.data.GPS_lat])
                .addTo(this.mapModal));

        },

        openMapconfig() {
            this.Mapconfig = true;

            setTimeout(() => {

                // creating map
                this.mapModal = new mapboxgl.Map({
                attributionControl: false,
                container: "mapModal",
                style: 'mapbox://styles/datakorum-develop/cl4cu370w000v15tal53sxn9v',
                center: [this.data.GPS_lng, this.data.GPS_lat],
                zoom: 15,
                pitch: 50,
                bearing: 0,
                });

                this.markers = [];

                let img = document.createElement('img');
                img.src = this.str_img;

                let markerElement = document.createElement('div')
                markerElement.appendChild(img)

                this.markers.push(new mapboxgl.Marker({ element: markerElement })
                    .setLngLat([this.data.GPS_lng, this.data.GPS_lat])
                    .addTo(this.mapModal));

                this.mapModal.on("click", (event) => {

                    this.data.GPS_lat = event.lngLat.lat,
                    this.data.GPS_lng = event.lngLat.lng

                    this.mapModal.flyTo({
                        center: [this.data.GPS_lng, this.data.GPS_lat],
                        essential: true,
                    });

                    // eliminar todos los marcadores existentes
                    this.markers.forEach(marker => marker.remove());
                    this.markers = [];

                    this.markers.push(new mapboxgl.Marker({ element: markerElement })
                        .setLngLat([this.data.GPS_lng, this.data.GPS_lat])
                        .addTo(this.mapModal));

                    this.MapChange_var = false;
                });

            }, 0);

        },

        CancelGateway() {
            document.getElementById('id_gateway_name').value = this.data.name
            this.GatewayChange()
        },

        CancelMap() {
            this.Mapconfig = false;

            if(this.data.GPS_lat != this.GPS_lat || this.data.GPS_lng != this.GPS_lng){
                this.data.GPS_lat = this.GPS_lat;
                this.data.GPS_lng = this.GPS_lng;
                this.rechargePage();
            }
        },

        SaveGateway() {

            var gateway_name;
            if (document.getElementById('id_gateway_name').value != this.data.name) {
                gateway_name = document.getElementById('id_gateway_name').value;
            } else {
                gateway_name = this.data.name;
            }

            var gateway_lat = this.GPS_lat;
            var gateway_lng = this.GPS_lng;

            const data = {
                name: gateway_name,
                GPS_lat: parseFloat(gateway_lat),
                GPS_lng: parseFloat(gateway_lng)
            };

            window.emitter.emit('changeLoaderStatus', true, 'orbit')

            axios({
                method: 'put',
                url: window.location.origin + '/api/gateway/edit/' + this.user.id + '/' + this.data.id,
                headers: {
                    'Accept': 'application/json',
                    'Content-Type': 'application/json',
                    'Authorization': 'Bearer ' + this.user.token
                },
                data: data
            })
                .then((response) => {

                    this.data.name = gateway_name
                    this.data.GPS_lat = gateway_lat,
                    this.data.GPS_lng = gateway_lng

                    this.rechargePage();
                    this.GatewayChange()

                    window.emitter.emit('changeLoaderStatus', false, 'orbit')

                })
                .catch((error) => {
                window.emitter.emit('changeLoaderStatus', false, 'orbit')

                if(error.response && error.response.status && error.response.status == 429){
                  window.alert( this.$t('text.Api attempts'));
                }else{
                  return "Failed!", error;
                }
              });
        },

        SaveMap(){

            if(this.data.GPS_lat != this.GPS_lat || this.data.GPS_lng != this.GPS_lng){

                const data = {
                    name: this.data.name,
                    GPS_lat: parseFloat(this.data.GPS_lat),
                    GPS_lng: parseFloat(this.data.GPS_lng)
                };

                window.emitter.emit('changeLoaderStatus', true, 'orbit')

                axios({
                    method: 'put',
                    url: window.location.origin + '/api/gateway/edit/' + this.user.id + '/' + this.data.id,
                    headers: {
                        'Accept': 'application/json',
                        'Content-Type': 'application/json',
                        'Authorization': 'Bearer ' + this.user.token
                    },
                    data: data
                })
                    .then((response) => {

                        this.data.GPS_lat = gateway_lat
                        this.data.GPS_lng = gateway_lng

                        this.GPS_lat = gateway_lat
                        this.GPS_lng = gateway_lng

                        window.emitter.emit('changeLoaderStatus', false, 'orbit')

                    })
                    .catch((error) => {
                        window.emitter.emit('changeLoaderStatus', false, 'orbit')

                        if(error.response && error.response.status && error.response.status == 429){
                        window.alert( this.$t('text.Api attempts'));
                        }else{

                        return "Failed!", error;
                        }
                    });

                this.rechargePage();

            }else {

                this.data.GPS_lat = this.GPS_lat
                this.data.GPS_lng = this.GPS_lng

            }

            this.Mapconfig = false;

        },

        getMarker(service){
            switch(service){
                case 'Domiciliario': return 'domiciliaryLang';
                case 'Distribución': return 'distributionLang';
                case 'Control de presión': return 'pressureLang';
                case 'Calidad de agua': return 'waterQualityLang';
                case 'Nivel de agua': return 'waterLevelLang';
            }

            return 'domiciliaryLang';
        }
    },
}
</script>
